package com.ruoyi.web.controller.app;

import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson2.JSON;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.constant.Constants;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.domain.entity.AsArticleClassify;
import com.ruoyi.common.core.domain.entity.EUser;
import com.ruoyi.common.core.domain.entity.SysDictData;
import com.ruoyi.common.core.domain.model.LoginBody;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.framework.web.service.SysLoginService;
import com.ruoyi.system.city.domain.RlCity;
import com.ruoyi.system.city.domain.RlCityQuery;
import com.ruoyi.system.city.service.IRlCityService;
import com.ruoyi.system.domain.EtArticle;
import com.ruoyi.system.domain.order.EOrderQuery;
import com.ruoyi.system.domain.rule.EFeeRuleVO;
import com.ruoyi.system.domain.store.EStoreQuery;
import com.ruoyi.system.domain.vo.PriceVO;
import com.ruoyi.system.intention.domain.EIntention;
import com.ruoyi.system.intention.service.IEIntentionService;
import com.ruoyi.system.model.service.IEModelService;
import com.ruoyi.system.service.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

/**
 * app接口（不需要登录的）
 *  校验
 * @author ruoyi
 */
@RestController
@RequestMapping("/app")
public class AppController extends BaseController
{

    @Autowired
    private ISysDictDataService dictDataService;

    @Autowired
    private IEModelService modelService;

    @Autowired
    private IEFeeRuleService rlFeeRuleService;

//    @Autowired
//    private IEDeviceService eDeviceService;

    @Resource
    private IEOrderService orderService;

    @Autowired
    private IEArticleService asArticleService;

    @Autowired
    private IEArticleClassifyService asArticleClassifyService;

    @Resource
    private IEUserService userService;

    @Autowired
    private SysLoginService loginService;

    @Resource
    private IRlCityService rlCityService;

    @Autowired
    private IEStoreService storeService;

    @Autowired
    private IEIntentionService intentionService;

    @Autowired
    private IEFeeRuleService feeRuleService;

    /**
     * 验证码登录
     */
    @PostMapping("/appCodeLogin")
    public AjaxResult appCodeLogin(@RequestBody LoginBody loginBody) {
        AjaxResult ajax = AjaxResult.success();
        /**通过手机号找到用户名*/
        String phone = loginBody.getPhone();
        // 生成令牌
        String token = loginService.appCodeLogin(phone, loginBody.getPhoneCode(),loginBody.getPassword(), loginBody.getUuid());
        ajax.put(Constants.TOKEN, token);
        return ajax;
    }

    /**
     * 获取字典类型列表
     */
    @GetMapping("/getDictData")
    public AjaxResult cityList(String dictType)
    {
        SysDictData sysDictData = new SysDictData();
        sysDictData.setDictType(dictType);
        List<SysDictData> list = dictDataService.selectDictDataList(sysDictData);
        return success(list);
    }

    /**
     * 查询已开通城市列表
     */
    @GetMapping("/city/list")
    public AjaxResult cityList(RlCityQuery city)
    {
        logger.info("查询城市列表：【city={}】", city);
        city.setIsOpen(true);
        List<RlCity> list = rlCityService.selectRlCityList(city);
        return success(list);
    }

    /**
     * 根据定位获取哪个城市
     */
    @GetMapping("/getCity")
    public AjaxResult getCity(String lon,String lat)
    {
        logger.info("根据定位获取哪个城市：【lon="+lon+",lat="+lat+"】");
        AjaxResult ajax = AjaxResult.success();
        RlCity city = rlCityService.getCityByLocation(lon, lat);
        ajax.put(AjaxResult.DATA_TAG, city);
        return ajax;
    }

    /**
      * 根据定位获取附近店铺列表
      */
    @PostMapping("/getStoreListByLocation")
    public AjaxResult getStoreListByLocation(@RequestBody EStoreQuery query)
    {
        logger.info("根据定位获取附近店铺列表：【StoreQuery={}】", JSON.toJSONString(query));
        if(StrUtil.isBlank(query.getPhoneLon())){
            return error("经度[phoneLon]未传");
        }
        if(StrUtil.isBlank(query.getPhoneLat())){
            return error("纬度[phoneLat]未传");
        }
        return success(storeService.getStoreListByLocation(query));
    }

    /**
     * 提交加盟合作
     */
    @Log(title = "合作意向", businessType = BusinessType.INSERT)
    @PostMapping("/intention")
    public AjaxResult add(@RequestBody EIntention eIntention)
    {
        logger.info("提交加盟合作：【EIntention={}】", JSON.toJSONString(eIntention));
        return toAjax(intentionService.insertEIntention(eIntention));
    }


    /**
     * 根据房间id获取套餐
     */
    @GetMapping("/getRuleListByRoomId")
    public AjaxResult ruleList(Long roomId)
    {
        logger.info("根据房间id获取套餐：【roomId={}】", roomId);
        List<EFeeRuleVO> list = feeRuleService.selectEFeeRuleListByRoomId(roomId);
        return success(list);
    }

    /**
     * 根据车型id获取详情
     */
    @GetMapping("/getModelById")
    public AjaxResult getModelById(Long modelId)
    {
        logger.info("根据车型id获取详情：【modelId="+modelId+"】");
        if(modelId==null){
            return error("车型id[modelId]未传");
        }
//        modelService.selectEModelByModelId(modelId);
        return success();
    }

    /**
     * 根据车型id获取功能
     */
    @GetMapping("/getFunctionListByModelId")
    public AjaxResult getFunctionListByModelId(Long modelId)
    {
        logger.info("根据车型id获取功能：【modelId="+modelId+"】");
        //判空
        if(modelId == null){
            return error("参数[modelId]不能为空");
        }
//        List<EFunction> functionList = modelService.getFunctionListByModelId(modelId);
        return success();
    }

    /**
     * 计算价格
     */
    @PostMapping("/calculatePrice")
    public AjaxResult calculatePrice(@RequestBody EOrderQuery order)
    {
        logger.info("【计算价格】请求参数：order={}", JSON.toJSONString(order));
        if(order.getModelId() == null){
            return error("车型id不能为空");
        }
        if(order.getRuleId() == null){
            return error("计费规则id不能为空");
        }
//        if(order.getAgentId() == null){
//            return error("代理商id不能为空");
//        }
//        if(order.getDeliveryMethod() == null){
//            return error("配送方式不能为空");
//        }
        if(StrUtil.isBlank(order.getType())){
            return error("类型不能为空");
        }
        PriceVO priceVO = orderService.calculatePrice(order);
        return AjaxResult.success(priceVO);
    }

    /**
     * 查询文章列表
     */
    @GetMapping("/article/list")
    public TableDataInfo articleList(EtArticle etArticle)
    {
        startPage();
        List<EtArticle> list = asArticleService.selectAsArticleListByApp(etArticle);
        return getDataTable(list);
    }

    /**
     * 获取文章详细信息
     */
    @GetMapping(value = "/article/{articleId}")
    public AjaxResult getArticleInfo(@PathVariable("articleId") Long articleId)
    {
        return success(asArticleService.selectAsArticleByArticleId(articleId));
    }

    /**
     * 根据查询文章分类列表
     */
    @GetMapping("/classify/list")
    public AjaxResult classifyList(AsArticleClassify asArticleClassify)
    {
        logger.info("查询分类列表：【asArticleClassify="+asArticleClassify+"】");
        List<AsArticleClassify> asArticleClassifies = asArticleClassifyService.selectClassifyList(asArticleClassify);
        return success(asArticleClassifies);
    }

    /**
     * 修改用户类型
     */
    @PostMapping("/changeUserType")
    public AjaxResult changeUserType(Long userId, String userType)
    {
        EUser user = new EUser();
        user.setUserId(userId);
        user.setUserType(userType);
        return toAjax(userService.updateUser(user));
    }

}
